==> crnk-core-2.5.20180326154333-sources.jar: io/crnk/core/engine/internal/information/repository/ResourceRepositoryInformationImpl.java <==
package io.crnk.core.engine.internal.information.repository;

import io.crnk.core.engine.information.repository.RepositoryAction;
import io.crnk.core.engine.information.repository.RepositoryMethodAccess;
import io.crnk.core.engine.information.repository.ResourceRepositoryInformation;
import io.crnk.core.engine.information.resource.ResourceInformation;
import io.crnk.core.utils.Optional;

import java.util.HashMap;
import java.util.Map;

public class ResourceRepositoryInformationImpl implements ResourceRepositoryInformation {

	private ResourceInformation resourceInformation;

	private String resourceType;

	private String path;

	private Map<String, RepositoryAction> actions;

	private RepositoryMethodAccess access;

	@Deprecated
	public ResourceRepositoryInformationImpl(String path, ResourceInformation resourceInformation,
			RepositoryMethodAccess access) {
		this(path, resourceInformation, new HashMap<String, RepositoryAction>(), access);
	}

	@Deprecated
	public ResourceRepositoryInformationImpl(String path,
			ResourceInformation resourceInformation, Map<String, RepositoryAction> actions, RepositoryMethodAccess access) {
		this.resourceInformation = resourceInformation;
		this.path = path;
		this.actions = actions;
		this.resourceType = resourceType;
		this.access = access;
	}

	@Override
	public Optional<ResourceInformation> getResourceInformation() {
		return Optional.of(getResource());
	}

	@Override
	public ResourceInformation getResource() {
		return resourceInformation;
	}

	@Override
	public String getResourceType() {
		return resourceType;
	}

	@Override
	public String getPath() {
		return path;
	}

	@Override
	public Map<String, RepositoryAction> getActions() {
		return actions;
	}

	@Override
	public RepositoryMethodAccess getAccess() {
		return access;
	}
}

==> crnk-core-2.11.20190113153635-sources.jar: io/crnk/core/engine/internal/information/repository/ResourceRepositoryInformationImpl.java <==
package io.crnk.core.engine.internal.information.repository;

import io.crnk.core.engine.information.repository.RepositoryAction;
import io.crnk.core.engine.information.repository.RepositoryMethodAccess;
import io.crnk.core.engine.information.repository.ResourceRepositoryInformation;
import io.crnk.core.engine.information.resource.ResourceInformation;

import java.util.Map;
import java.util.Optional;

public class ResourceRepositoryInformationImpl implements ResourceRepositoryInformation {

	private ResourceInformation resourceInformation;


	private String path;

	private Map<String, RepositoryAction> actions;

	private RepositoryMethodAccess access;

	private boolean exposed;

	public ResourceRepositoryInformationImpl(String path,
											 ResourceInformation resourceInformation, Map<String, RepositoryAction> actions,
											 RepositoryMethodAccess access, boolean exposed) {
		this.resourceInformation = resourceInformation;
		this.path = path;
		this.actions = actions;
		this.access = access;
		this.exposed = exposed;
	}

	@Override
	public Optional<ResourceInformation> getResourceInformation() {
		return Optional.of(getResource());
	}

	@Override
	public ResourceInformation getResource() {
		return resourceInformation;
	}

	@Override
	public String getResourceType() {
		return resourceInformation.getResourceType();
	}

	@Override
	public String getPath() {
		return path;
	}

	@Override
	public Map<String, RepositoryAction> getActions() {
		return actions;
	}

	@Override
	public boolean isExposed() {
		return exposed;
	}

	@Override
	public RepositoryMethodAccess getAccess() {
		return access;
	}
}
